# -*- coding: utf-8 -*-
import logging
from functools import wraps

__all__ = ['loggable_method']

def loggable_method(name):
    """
    Wraps a method to set logger on self.logger
    """
    def dec(func):
        @wraps(func)
        def wrapper(self, *args, **kw):
            try:
                self.logger = logging.getLogger(name)
            except Exception as e:
                pass
            result = func(self, *args, **kw)
            return result
        return wrapper
    if hasattr(name, '__call__'):
        return dec(name)
    return dec


from distutils.core import setup
setup(
  name = 'loggable-decorator',
  packages = ['loggable'],
  version = '1.0.0',
  description = 'Add a logger attribute to class decorated',
  author = 'Peter Downs',
  author_email = 'peterldowns@gmail.com',
  url = 'https://github.com/ateliedocodigo/python-loggable-decorator',
  download_url = 'https://github.com/ateliedocodigo/python-loggable-decorator/tarball/1.0.0',
  keywords = ['logging'],
  classifiers = [],
)
